@@ -30,7 +30,7 @@ LOGGER = getLogger("PyLav.Node")
 
 
 class Penalty:
-    """Represents the penalty of the stats of a Node."""
+    """Represents the penalty of the stats of a Node"""
 
     __slots__ = ("_stats",)
 
@@ -47,12 +47,12 @@ class Penalty:
 
     @property
     def cpu_penalty(self) -> float:
-        """The penalty of the cpu load of the node."""
+        """The penalty of the cpu load of the node"""
         return 1.05 ** (100 * self._stats.system_load) * 10 - 10
 
     @property
     def null_frame_penalty(self) -> float | int:
-        """The penalty of the nulled frames of the node."""
+        """The penalty of the nulled frames of the node"""
         null_frame_penalty = 0
         if self._stats.frames_nulled != -1:
             null_frame_penalty = (1.03 ** (500 * (self._stats.frames_nulled / 3000))) * 300 - 300
@@ -61,7 +61,7 @@ class Penalty:
 
     @property
     def deficit_frame_penalty(self) -> float | int:
-        """The penalty of the deficit frames of the node."""
+        """The penalty of the deficit frames of the node"""
         return (
             1.03 ** (500 * (self._stats.frames_deficit / 3000)) * 600 - 600 if self._stats.frames_deficit != -1 else 0
         )
@@ -76,7 +76,7 @@ class Penalty:
 
 
 class Stats:
-    """Represents the stats of Lavalink node."""
+    """Represents the stats of Lavalink node"""
 
     __slots__ = (
         "_node",
@@ -97,57 +97,57 @@ class Stats:
 
     @property
     def uptime(self) -> int:
-        """How long the node has been running for in milliseconds."""
+        """How long the node has been running for in milliseconds"""
         return self._data["uptime"]
 
     @property
     def uptime_seconds(self) -> float:
-        """How long the node has been running for in seconds."""
+        """How long the node has been running for in seconds"""
         return self.uptime / 1000
 
     @property
     def players(self) -> int:
-        """The amount of players connected to the node."""
+        """The amount of players connected to the node"""
         return self._data["players"]
 
     @property
     def playing_players(self) -> int:
-        """The amount of players that are playing in the node."""
+        """The amount of players that are playing in the node"""
         return self._data["playingPlayers"]
 
     @property
     def memory_free(self) -> int:
-        """The amount of memory free to the node."""
+        """The amount of memory free to the node"""
         return self._memory["free"]
 
     @property
     def memory_used(self) -> int:
-        """The amount of memory that is used by the node."""
+        """The amount of memory that is used by the node"""
         return self._memory["used"]
 
     @property
     def memory_allocated(self) -> int:
-        """The amount of memory allocated to the node."""
+        """The amount of memory allocated to the node"""
         return self._memory["allocated"]
 
     @property
     def memory_reservable(self) -> int:
-        """The amount of memory reservable to the node."""
+        """The amount of memory reservable to the node"""
         return self._memory["reservable"]
 
     @property
     def cpu_cores(self) -> int:
-        """The amount of cpu cores the system of the node has."""
+        """The amount of cpu cores the system of the node has"""
         return self._cpu["cores"]
 
     @property
     def system_load(self) -> float:
-        """The overall CPU load of the system."""
+        """The overall CPU load of the system"""
         return self._cpu["systemLoad"]
 
     @property
     def lavalink_load(self) -> float:
-        """The CPU load generated by Lavalink."""
+        """The CPU load generated by Lavalink"""
         return self._cpu["lavalinkLoad"]
 
     @property
@@ -161,7 +161,7 @@ class Stats:
 
     @property
     def frames_nulled(self) -> int:
-        """The number of frames that yielded null, rather than actual data."""
+        """The number of frames that yielded null, rather than actual data"""
         return self._frame_stats.get("nulled", -1)
 
     @property
@@ -174,7 +174,7 @@ class Stats:
 
     @property
     def penalty(self) -> Penalty:
-        """The penalty for the node."""
+        """The penalty for the node"""
         return self._penalty
 
 
@@ -234,7 +234,7 @@ class Node:
         self._config = None  # type: ignore
 
         if self._manager.get_node_by_id(unique_identifier) is not None:
-            raise ValueError(f"A Node with identifier:{unique_identifier} already exists.")
+            raise ValueError(f"A Node with identifier:{unique_identifier} already exists")
         self._identifier = unique_identifier
         self._ssl = ssl
         if port is None:
@@ -305,67 +305,67 @@ class Node:
 
     @property
     def websocket(self) -> WebSocket:
-        """The websocket of the node."""
+        """The websocket of the node"""
         return self._ws
 
     @property
     def node_manager(self) -> NodeManager:
-        """The :class:`NodeManager` this node belongs to."""
+        """The :class:`NodeManager` this node belongs to"""
         return self._manager
 
     @property
     def port(self) -> int:
-        """The port of the node."""
+        """The port of the node"""
         return self._port
 
     @property
     def ssl(self) -> bool:
-        """Whether the node is using a ssl connection."""
+        """Whether the node is using a ssl connection"""
         return self._ssl
 
     @property
     def connection_protocol(self) -> str:
-        """The protocol used for the connection."""
+        """The protocol used for the connection"""
         return "https" if self.ssl else "http"
 
     @property
     def host(self) -> str:
-        """The host of the node."""
+        """The host of the node"""
         return self._host
 
     @property
     def region(self) -> str:
-        """The region of the node."""
+        """The region of the node"""
         return self._region
 
     @property
     def name(self) -> str:
-        """The name of the node."""
+        """The name of the node"""
         return self._name
 
     @property
     def password(self) -> str:
-        """The password of the node."""
+        """The password of the node"""
         return self._password
 
     @property
     def resume_key(self) -> str:
-        """The resume key of the node."""
+        """The resume key of the node"""
         return self._resume_key
 
     @property
     def resume_timeout(self) -> int:
-        """The timeout to use for resuming."""
+        """The timeout to use for resuming"""
         return self._resume_timeout
 
     @property
     def reconnect_attempts(self) -> int:
-        """The number of attempts to reconnect to the node."""
+        """The number of attempts to reconnect to the node"""
         return self._reconnect_attempts
 
     @property
     def stats(self) -> Stats:
-        """The stats of the node."""
+        """The stats of the node"""
         return self._stats
 
     @stats.setter
@@ -376,63 +376,63 @@ class Node:
 
     @property
     def available(self) -> bool:
-        """Returns whether the node is available for requests."""
+        """Returns whether the node is available for requests"""
         return self._ws.connected if self._ws else False
 
     @property
     def _original_players(self) -> list[Player]:
-        """Returns a list of players that were assigned to this node, but were moved due to failover etc."""
+        """Returns a list of players that were assigned to this node, but were moved due to failover etc"""
         return [p for p in self._manager.client.player_manager.players.values() if p._original_node == self]
 
     @property
     def players(self) -> list[Player]:
-        """Returns a list of all players on this node."""
+        """Returns a list of all players on this node"""
         return [p for p in self._manager.client.player_manager.players.values() if p.node == self]
 
     @property
     def playing_players(self) -> list[Player]:
-        """Returns a list of all players on this node that are playing."""
+        """Returns a list of all players on this node that are playing"""
         return [p for p in self.players if p.is_playing]
 
     @property
     def connected_players(self) -> list[Player]:
-        """Returns a list of all players on this node that are connected."""
+        """Returns a list of all players on this node that are connected"""
         return [p for p in self.players if p.is_connected]
 
     @property
     def server_connected_players(self) -> int:
-        """Returns the number of players on this node that are connected."""
+        """Returns the number of players on this node that are connected"""
         return self.stats.players if self.stats else len(self.connected_players)
 
     @property
     def server_playing_players(self) -> int:
-        """Returns the number of players on this node that are playing."""
+        """Returns the number of players on this node that are playing"""
         return self.stats.playing_players if self.stats else len(self.playing_players)
 
     @property
     def count(self) -> int:
-        """Returns the number of players on this node."""
+        """Returns the number of players on this node"""
         return len(self.players)
 
     @property
     def playing_count(self) -> int:
-        """Returns the number of players on this node that are playing."""
+        """Returns the number of players on this node that are playing"""
         return len(self.playing_players)
 
     @property
     def connected_count(self) -> int:
-        """Returns the number of players on this node that are connected."""
+        """Returns the number of players on this node that are connected"""
         return len(self.connected_players)
 
     @property
     def penalty(self) -> float:
-        """Returns the load-balancing penalty for this node."""
+        """Returns the load-balancing penalty for this node"""
         if not self.available or not self.stats:
             return float("inf")
         return self.stats.penalty.total
 
     async def penalty_with_region(self, region: str | None) -> float:
-        """The penalty for the node, with the region added in."""
+        """The penalty for the node, with the region added in"""
         if not region:
             return self.penalty
         return self.penalty + (1.1 ** (0.0025 * await self.region_distance(region)) * 500 - 500)
@@ -1258,7 +1258,4 @@ class Node:
         """
         coordinates = REGION_TO_COUNTRY_COORDINATE_MAPPING.get(region)
 
-        if not (coordinates and self.coordinates):
-            return float("inf")
-
-        return distance(*self.coordinates, *coordinates)
+        return distance(*self.coordinates, *coordinates) if (coordinates and self.coordinates) else float("inf")
